@@ -48,14 +48,24 @@ def clone(cnvrg, logger, name, override, cache_link, commit, threads, query):
 @click.option('-fc', '--force', is_flag=True, help=messages.DATA_UPLOAD_HELP_FORCE)
 @click.option('-or', '--override', is_flag=True, help=messages.DATA_UPLOAD_HELP_OVERRIDE)
 @click.option('-gd', '--git-diff', is_flag=True, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
+@click.option('-t', '--threads', default=40, type=int, help=messages.DATA_UPLOAD_HELP_THREADS)
+@click.option('-c', '--chunks', default=1000, type=int, help=messages.DATA_UPLOAD_HELP_CHUNKS)
 @prepare_command()
-def put(cnvrg, logger, name, files, force, override, git_diff):
+def put(cnvrg, logger, name, files, force, override, git_diff, threads, chunks):
     """
     Uploads the given files to the given dataset
     """
     file_paths = files.split(",")
     dataset = cnvrg.datasets.get(name)
-    dataset.put_files(paths=file_paths, progress_bar_enabled=True, git_diff=git_diff, force=force, override=override)
+    dataset.put_files(
+        paths=file_paths,
+        progress_bar_enabled=True,
+        git_diff=git_diff,
+        force=force,
+        override=override,
+        threads=threads,
+        chunks=chunks
+    )
     logger.log_and_echo(messages.DATA_UPLOAD_SUCCESS)
 
 
