@@ -18,7 +18,7 @@ def create(project, logger, yaml_path):
     Creates a flow from a predefined yaml file
     """
     try:
-        flow = project.flows.create(yaml_path)
+        flow = project.flows.create(yaml_path=yaml_path)
         success_message = messages.FLOW_CREATE_SUCCESS.format(flow.title)
         logger.log_and_echo(success_message)
     except CnvrgFileError as e:
