@@ -43,17 +43,21 @@ def create(cnvrg, logger, name):
 @click.option('-o', '--override', is_flag=True, default=False, help=messages.PROJECT_HELP_CLONE_OVERRIDE)
 @click.option('-c', '--commit', prompt=messages.DATA_PROMPT_COMMIT, default="latest",
               help=messages.PROJECT_HELP_CLONE_COMMIT)
+@click.option('-d', '--current_dir', help=messages.PROJECT_HELP_CURRENT_DIR, is_flag=True, default=False)
 @prepare_command()
-def clone(cnvrg, logger, name, override, commit):
+def clone(cnvrg, logger, name, override, commit, current_dir):
     """
     Clones the given project to local folder
     """
     project = cnvrg.projects.get(name)
     logger.info(messages.LOG_CLONING_PROJECT.format(name))
-    if os.path.exists(project.slug + '/' + CONFIG_FOLDER_NAME) and not override:
+    config_path = project.slug + '/' + CONFIG_FOLDER_NAME
+    if current_dir:
+        config_path = CONFIG_FOLDER_NAME
+    if os.path.exists(config_path) and not override:
         logger.log_and_echo(messages.PROJECT_CLONE_SKIP.format(name))
         return
-    project.clone(progress_bar_enabled=True, override=override, commit=commit)
+    project.clone(progress_bar_enabled=True, override=override, commit=commit, current_dir=current_dir)
     success_message = messages.PROJECT_CLONE_SUCCESS.format(name)
     logger.log_and_echo(success_message)
 
@@ -168,6 +172,10 @@ def link_git(cnvrg, logger, name, soft):
     if not cnvrgignore_exists(os.getcwd()):
         create_cnvrgignore(os.getcwd())
 
+    output_folder = os.environ.get('CNVRG_OUTPUT_DIR')
+    if output_folder and not os.path.isdir(output_folder):
+        os.makedirs(output_folder)
+
     success_message = messages.PROJECT_LINK_SUCCESS.format(git_proj.title)
     logger.log_and_echo(success_message)
 
@@ -177,15 +185,23 @@ def link_git(cnvrg, logger, name, soft):
 @click.option('-g', '--git-diff', is_flag=True, default=None, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
 @click.option('-m', '--message', default="", help=messages.DATA_COMMIT_MESSAGE)
 @click.option('-o', '--output-dir', default=None, help=messages.SYNC_OUTPUT_DIR)
+@click.option('-d', '--debug-mode', is_flag=True, default=False, help=messages.DEBUG_MODE_HELP)
 @prepare_command()
-def sync(project, logger, message, job_slug=None, git_diff=None, output_dir=None):
+def sync(project, logger, message, job_slug=None, git_diff=None, output_dir=None, debug_mode=None):
     """
     Sync local project to remote
     """
-    logger.log_and_echo('Syncing...')
-    project.sync(job_slug=job_slug, git_diff=git_diff, progress_bar_enabled=True, message=message,
-                 output_dir=output_dir)
-    logger.log_and_echo(messages.PROJECT_SYNC_SUCCESS.format(project.slug))
+    logger.log_and_echo('Syncing Project')
+
+    # store the last commit before syncing
+    start_commit = project.last_commit
+    commit_sha1 = project.sync(job_slug=job_slug, git_diff=git_diff, progress_bar_enabled=True, message=message,
+                               output_dir=output_dir, debug_mode=debug_mode)
+    # if the last commit is the same as the start commit before syncing, the project is up to date
+    if commit_sha1 is None or commit_sha1 == start_commit:
+        logger.log_and_echo(messages.PROJECT_IS_UP_TO_DATE.format(project.slug))
+    else:
+        logger.log_and_echo(messages.PROJECT_SYNC_SUCCESS.format(project.slug, commit_sha1))
 
 
 @project_group.command()
