@@ -19,7 +19,6 @@ from cnvrgv2.config import error_messages
 @click.option('-t', '--auth-token', default=None, help=messages.LOGIN_HELP_AUTH_TOKEN)
 @prepare_command_without_context()
 def login(logger, domain, email, password, organization, auth_token):
-
     config = Config()
     config_domain = None
     if password is None:
@@ -47,12 +46,14 @@ def login(logger, domain, email, password, organization, auth_token):
 
     try:
         uc = UsersClient(domain=domain, token=auth_token)
-        token, default_organization = uc.login(user=email, password=password)
+        config.sso_version = uc.sso_version
+
+        token, default_organization, sso_enabled = uc.login(user=email, password=password, token=auth_token)
 
         config.domain = domain
         config.organization = organization or default_organization
         config.user = email
-        if auth_token is not None:
+        if auth_token is not None and sso_enabled:
             config.token = auth_token
         else:
             config.token = token
