@@ -1,7 +1,8 @@
-import click
 import inspect
 from functools import wraps
 
+import click
+
 from cnvrgv2 import Cnvrg
 from cnvrgv2.cli.logger.logger import CnvrgLogger
 from cnvrgv2.cli.utils import messages
@@ -11,6 +12,7 @@ from cnvrgv2.config import error_messages
 from cnvrgv2.errors import CnvrgError
 from cnvrgv2.modules.workflows.endpoint.endpoint import Endpoint
 from cnvrgv2.modules.workflows.experiment.experiment import Experiment
+from cnvrgv2.modules.workflows.webapp.webapp import Webapp
 from cnvrgv2.modules.workflows.workspace.workspace import Workspace
 
 
@@ -20,13 +22,14 @@ def prepare_command():
     the cnvrg object and logger object to the cli command function, if the arguments are expected by the function
     @return: the decorator function
     """
+
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
             verify_login()
             cnvrg = Cnvrg()
             config = Config()
-            # In case the user logged in through the sdk, the config file might not exist. congig.save will create it
+            # In case the user logged in through the sdk, the config file might not exist. config.save will create it
             config.save()
             logger = CnvrgLogger(click)
             command_name = func.__name__
@@ -72,11 +75,19 @@ def prepare_command():
                     slug = kwargs.get("slug")
                     if slug and config.data_owner_slug:
                         inject_args["endpoint"] = cnvrg.projects.get(config.data_owner_slug).endpoints.get(slug)
+            if "webapp" in func_args:
+                try:
+                    inject_args["webapp"] = Webapp()
+                except CnvrgError:
+                    slug = kwargs.get("slug")
+                    if slug and config.data_owner_slug:
+                        inject_args["webapp"] = cnvrg.projects.get(config.data_owner_slug).webapps.get(slug)
 
             n_kwargs = {**kwargs, **inject_args}
             func(*args, **n_kwargs)
 
         return inner
+
     return decorator
 
 
