@@ -29,10 +29,13 @@ DATA_COMMIT_MESSAGE = "Commit message"
 DATA_UPLOAD_HELP_GIT_DIFF = "From the list of files, upload those who returned from git diff command."
 DATA_UPLOAD_HELP_FORCE = "Enable to create an empty commit without files from parent commit."
 DATA_UPLOAD_HELP_OVERRIDE = "Enable to re-upload even if the file already exists."
+DATA_UPLOAD_HELP_THREADS = "Number of threads that will be used to preform the upload"
+DATA_UPLOAD_HELP_CHUNKS = "Number of chunks that will be used to preform the upload"
 DATA_PROMPT_COMMIT = "Please enter sha1 to clone"
 DATA_PROMPT_CACHE = "Please enter sha1 to cache"
 DATA_DOWNLOAD_ERROR = "Unexpected error while executing command"
 SYNC_OUTPUT_DIR = "The directory that will be synced inside the project"
+DEBUG_MODE_HELP = "Enable to create start commit in debug mode"
 CLONE_NUMBER_OF_THREADS = "Number of threads that will be used to preform the clone"
 QUERY_SLUG = "Query slug"
 
@@ -109,7 +112,9 @@ PROJECT_CREATE_FOLDER_NOT_EMPTY = "Warning! You're about to associate a non empt
                                   "\r\nContinue?"
 PROJECT_CREATING_PROJECT = "Creating new project {0}"
 PROJECT_CREATE_SUCCESS = "Successfully created project {0}"
-PROJECT_SYNC_SUCCESS = "Successfully synced project {0}"
+PROJECT_SYNC_SUCCESS = "Successfully synced project {0}, commit_sha1: {1}"
+PROJECT_IS_UP_TO_DATE = "\N{check mark} Project {0} is up to date"
+PROJECT_HELP_CURRENT_DIR = "Wheteher or not to clone into the current directory"
 
 # FILES
 FILES_UPLOAD_SUCCESS = "Successfully uploaded files"
@@ -204,6 +209,11 @@ WORKSPACE_CREATE_SUCCESS = "Workspace {0} created successfully. \r\nWorkspace is
 WORKSPACE_HELP_COMMIT = "Sha1 of the commit to use, default: latest"
 WORKSPACE_HELP_LOCAL_FOLDERS = "Local folders to mount with workspace"
 
+# WEBAPP
+WEBAPP_HELP_SLUG = "Slug of the webapp"
+WEBAPP_HELP_FREQUENCY = "The frequency to pull the logs event in seconds"
+
+
 # ENDPOINT
 ENDPOINT_DOES_NOT_EXIST = "Endpoint was not found, check env or pass slug"
 ENDPOINT_SLUG = "Slug of the endpoint"
