@@ -40,7 +40,7 @@ class Cnvrg:
         Retrieves information about the current user
         @return: A dictionary representing the current logged in user
         """
-        users_client = UsersClient(self._context.domain, self._context.token, is_capi=self._context.is_capi)
+        users_client = UsersClient(self._context.domain, self._context.token)
         return users_client.me()
 
     def is_admin(self):
