@@ -61,6 +61,7 @@ LOCAL_COMMIT_DOESNT_EXIST_ERROR = "Local commit does not exist. Can't save confi
 # PROJECT
 PROJECT_GET_FAULTY_SLUG = "Cannot get project with empty slug or a non string slug"
 PROJECT_CREATE_FAULTY_NAME = "Cannot create project with empty/non-string name"
+PROJECT_ALREADY_CLONED = "Project already cloned"
 
 # LIBRARY
 LIBRARY_GET_FAULTY_SLUG = "Cannot get library with empty slug or a non string slug"
@@ -106,6 +107,7 @@ TEMPLATE_FAULTY_TYPE = 'Kube template type must be one of the following: [regula
 
 # CLONE
 CONFIG_YAML_NOT_FOUND = "Couldn't find config file. Please clone project/dataset before syncing."
+NOT_ENOUGH_SPACE = "Not enough space on disk to download dataset commit"
 
 # EXPERIMENT
 MISSING_EXPERIMENT_ARGUMENT = "The function sent as command must get experiment as an argument"
@@ -129,6 +131,9 @@ ENDPOINT_UPDATE_TIMEOUT = "Update endpoint {0} timeout"
 # WORKFLOW
 WORKFLOW_FINAL_STATE = "Workflow reached a final state {0}, different from desired one"
 
+# WEBAPP
+EXPERIMENT_SLUGS_NOT_FOUND = "Experiments slugs not found"
+
 # FLOW
 FLOW_GET_FAULTY_SLUG = "Cannot get flows with empty slug or a non string slug"
 FLOW_GET_FAULTY_YAML = "Yaml is not valid"
