@@ -117,7 +117,9 @@ EXPERIMENT_CHARTS_SUFFIX = "charts"
 EXPERIMENT_GET_UTILIZATION_SUFFIX = "get_utilization"
 EXPERIMENT_CHART_SUFFIX = "charts/{0}"
 EXPERIMENT_WRITE_LOGS = "write_logs"
-EXPERIMENT_LOGS_SUFFIX = "logs?offset=-1&search=&filter=[\"all\"]"
+EXPERIMENT_LOGS_SUFFIX = "logs?offset={0}&search={1}&filter={2}&page[after]={3}&page[before]={4}"
+EXPERIMENT_HYPER_SUFFIX = "hyper"
+EXPERIMENT_INFO_SUFFIX = "info"
 
 # WEBAPP
 WEBAPPS_BASE = "v2/{0}/projects/{1}/webapps/"
@@ -136,6 +138,7 @@ ENDPOINT_STATUS = "status"
 ENDPOINT_BATCH_SCALE_UP = "batch_scale_up"
 ENDPOINT_BATCH_SCALE_DOWN = "batch_scale_down"
 ENDPOINT_RULES = "rules"
+ENDPOINT_GET_PREDICTIONS = "get_predictions"
 
 # COMMON
 GET_BY_NAME_SUFFIX = "get_by_name"
