@@ -1,9 +1,9 @@
 from azure.storage.blob import BlobServiceClient
 
+from cnvrgv2.data.clients.base_storage_client import BaseStorageClient
 from cnvrgv2.utils.converters import convert_bytes
 from cnvrgv2.utils.retry import retry
 from cnvrgv2.utils.storage_utils import create_dir_if_not_exists
-from cnvrgv2.data.clients.base_storage_client import BaseStorageClient
 
 
 class AzureStorage(BaseStorageClient):
@@ -57,8 +57,11 @@ class AzureStorage(BaseStorageClient):
     @retry(log_error=True)
     def download_single_file(self, local_path, object_path, progress_bar=None):
         try:
-            client = self.service.get_blob_client(container=self.container_name, blob=object_path)
             create_dir_if_not_exists(local_path)
+            if not object_path:
+                return
+
+            client = self.service.get_blob_client(container=self.container_name, blob=object_path)
 
             with open(local_path, "wb") as local_file:
                 stream = client.download_blob(max_concurrency=1)
