@@ -10,16 +10,17 @@ from cnvrgv2.errors import CnvrgRetryError
 
 class RemoteFilesHandler:
     def __init__(
-            self,
-            data_owner,
-            num_workers=40,
-            chunk_size=1000,
-            use_cached=False,
-            force=False,
-            queue_size=5000,
-            base_commit_sha1=None,
-            commit_sha1=None,
-            progress_bar_enabled=False):
+        self,
+        data_owner,
+        num_workers=40,
+        chunk_size=1000,
+        use_cached=False,
+        force=False,
+        queue_size=5000,
+        base_commit_sha1=None,
+        commit_sha1=None,
+        progress_bar_enabled=False
+    ):
         """
         Multithreaded remote file handler base class
         @param data_owner: Cnvrg dataset / project object
@@ -36,8 +37,7 @@ class RemoteFilesHandler:
 
         # Init the storage client
         self.data_owner = data_owner
-        self.storage_meta = data_owner.storage_meta
-        self.storage_client = storage_client_factory(storage_meta=self.storage_meta)
+        self.storage_client = storage_client_factory(refresh_function=data_owner.storage_meta_refresh_function())
 
         self.use_cached = use_cached
         self.force = force
