@@ -6,6 +6,8 @@ import shutil
 import time
 from itertools import chain
 
+import psutil
+
 from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
 from cnvrgv2.config import Config
 from cnvrgv2.config import CONFIG_FOLDER_NAME
@@ -16,7 +18,8 @@ from cnvrgv2.data import FileCompare, LocalFileDeleter
 from cnvrgv2.data import FileDownloader
 from cnvrgv2.data import FileUploader
 from cnvrgv2.data import RemoteFileDeleter
-from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgFileError
+from cnvrgv2.errors import CnvrgAlreadyClonedError, CnvrgArgumentsError, CnvrgError, CnvrgFileError, \
+    CnvrgNotEnoughSpaceError
 from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
 from cnvrgv2.modules.file import File
 from cnvrgv2.modules.folder import Folder
@@ -103,7 +106,8 @@ class DataOwner(DynamicAttributes):
         """
         self._working_dir = working_dir
 
-    def _start_commit(self, message="", source="sdk", parent_sha1=None, blank=False, force=False, job_slug=None):
+    def _start_commit(self, message="", source="sdk", parent_sha1=None, blank=False,
+                      force=False, job_slug=None, debug_mode=False):
         """
         Starts a new commit
         @param message: Commit message string (Optional)
@@ -120,7 +124,8 @@ class DataOwner(DynamicAttributes):
             "job_slug": job_slug,
             "parent_sha1": parent_sha1,
             "source": source,
-            "message": message
+            "message": message,
+            "debug_mode": debug_mode
         }
         response = self._proxy.call_api(
             route=urljoin(self._route, "commits"),
@@ -176,11 +181,15 @@ class DataOwner(DynamicAttributes):
         upload=False,
         tag_images=False,
         progress_bar_enabled=False,
-        git_diff=False
+        git_diff=False,
+        debug_mode=False,
+        threads=40,
+        chunks=1000
     ):
         """
         Uploads the files and folders given.
         If a folder is given all the relevant files in that folder (that confirms to the regex) will be uploaded.
+        @param debug_mode: Force create master commit after debug
         @param paths: List of paths or unix-style wildcards
         @param message: String defining the commit message
         @param job_slug: Slug of a job to upload the files to
@@ -230,7 +239,8 @@ class DataOwner(DynamicAttributes):
             blank=blank,
             parent_sha1=last_commit,
             job_slug=job_slug,
-            force=force
+            force=force,
+            debug_mode=debug_mode
         )
 
         uploader = self._get_file_uploader(
@@ -238,7 +248,10 @@ class DataOwner(DynamicAttributes):
             commit=commit_sha1,
             metadata=metadata,
             override=override,
-            progress_bar_enabled=progress_bar_enabled
+            progress_bar_enabled=progress_bar_enabled,
+            num_workers=threads,
+            chunk_size=chunks
+
         )
         while uploader.in_progress:
             time.sleep(0.1)
@@ -265,7 +278,7 @@ class DataOwner(DynamicAttributes):
         # In the case nothing has actually been updated to the server, return last_commit
         return commit if commit else self.last_commit
 
-    def _get_file_uploader(self, paths, commit, metadata, override, progress_bar_enabled):
+    def _get_file_uploader(self, paths, commit, metadata, override, progress_bar_enabled, num_workers, chunk_size):
         # this is required for mocking. please don't delete the wrapping function
         return FileUploader(
             data_owner=self,
@@ -273,7 +286,10 @@ class DataOwner(DynamicAttributes):
             commit=commit,
             metadata=metadata,
             override=override,
-            progress_bar_enabled=progress_bar_enabled
+            progress_bar_enabled=progress_bar_enabled,
+            num_workers=num_workers,
+            chunk_size=chunk_size
+
         )
 
     def _handle_git_files(self):
@@ -352,47 +368,51 @@ class DataOwner(DynamicAttributes):
         commit=None,
         use_cached=False,
         threads=40,
-        query_slug=None
+        fullpath_filter=None,
+        query_slug=None,
+        current_dir=False,
+        check_disk_space=True,
     ):
         """
         Clones the remote project / dataset
+        @param query_slug: [String] the slug of a query
+        @param fullpath_filter: [String] Filter on path of file by part of the path
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param override: Boolean stating whether we should re-clone even if the project / dataset already cloned
         @param commit: [String] sha1 of the commit to clone
         @param use_cached: Boolean stating whether to use nfs cache link or not
         @param threads: number of threads that will be used in order to clone the project
+        @param current_dir: Boolean indicating whether to clone to the current dir or not
+        @param check_disk_space: Boolean stating whether to check there is enough space for dataset
         @return: None
         """
         self.reload()
 
-        if not os.path.exists(self.slug):
-            os.makedirs(self.slug)
-        elif os.path.exists(self.slug + '/' + CONFIG_FOLDER_NAME):
-            if not override:
-                # If already cloned and override set to false - won't clone again
-                return
-            else:
-                # If already cloned and override set to true - remove config file so that verify will fail until the
-                # data owner is cloned again
-                shutil.rmtree(self.slug + '/' + CONFIG_FOLDER_NAME)
+        old_working_dir = self.working_dir
+        try:
+            self._prepare_cloned_directory(old_working_dir, current_dir, override)
+        except CnvrgAlreadyClonedError:
+            return
 
         if commit and commit.lower() != 'latest':
             # self.last_commit should be a value returned from the server,
             # and no value should be manually assigned to it.
             # this is a workaround for cloning a specific commit:
             # because FileDownloader uses self.last_commit instead of receiving commit as an arg
-            # todo : pass commit to FileDownloader
+            # TODO : pass commit to FileDownloader
 
             self.last_commit = commit
 
-        old_working_dir = self.working_dir
-        self.working_dir = "{}/{}".format(old_working_dir, self.slug)
+        # checking if there is enough disk space available for a specific commit,
+        # considering a decrease percentage for the free space
+        if check_disk_space:
+            self._should_have_enough_space_to_download_commit(self.last_commit)
 
         # Will download files from self.last_commit.
         # In the case of cloning a specific commit, last_commit is actually that specific commit assigned previously
 
         downloader = FileDownloader(self, progress_bar_enabled=progress_bar_enabled, use_cached=use_cached,
-                                    num_workers=threads, query_slug=query_slug)
+                                    num_workers=threads, query_slug=query_slug, fullpath_filter=fullpath_filter)
 
         while downloader.in_progress:
             time.sleep(1)
@@ -407,13 +427,13 @@ class DataOwner(DynamicAttributes):
         self.local_commit = self.last_commit
         self.save_config(local_config_path=self.working_dir + '/' + CONFIG_FOLDER_NAME)
 
+        if not cnvrgignore_exists(self.working_dir):
+            create_cnvrgignore(self.working_dir)
+
         # Reload will reset self.last_commit to the actual data_owner last_commit in case it has been changed previously
         self.reload()
         self.working_dir = old_working_dir
 
-        if not cnvrgignore_exists(self.slug):
-            create_cnvrgignore(self.slug)
-
     def upload(
         self,
         sync=False,
@@ -421,17 +441,19 @@ class DataOwner(DynamicAttributes):
         progress_bar_enabled=False,
         git_diff=False,
         message="",
-        output_dir=None
+        output_dir=None,
+        debug_mode=False
     ):
         """
         Uploads files to remote project / dataset
+        @param debug_mode: Force create master commit after debug
         @param sync: Boolean gives info if the put files comes from sync or not
         @param job_slug: Slug of a job to upload the files to
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param git_diff: upload only files from git diff output
         @param message: String defining the commit message
         @param output_dir: String will only upload the files in the output_dir specified
-        @return: None
+        @return: new commit sha1
         """
 
         # We want to make sure we are in a project/dataset folder in order to continue with the action
@@ -449,7 +471,8 @@ class DataOwner(DynamicAttributes):
             job_slug=job_slug,
             progress_bar_enabled=progress_bar_enabled,
             git_diff=git_diff,
-            message=message
+            message=message,
+            debug_mode=debug_mode
         )
 
         if sync:
@@ -459,6 +482,8 @@ class DataOwner(DynamicAttributes):
         self.save_config()
         os.chdir(old_working_dir)
 
+        return new_commit_sha1
+
     def download(self, sync=False, progress_bar_enabled=False):
         """
         Download files from remote project / dataset
@@ -515,20 +540,26 @@ class DataOwner(DynamicAttributes):
 
         os.chdir(context_working_dir)
 
-    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False, message='', output_dir=None):
+    def sync(self, job_slug=None, git_diff=False, progress_bar_enabled=False, message='',
+             output_dir=None, debug_mode=False):
         """
         Sync local project / dataset to remote
+        @param debug_mode: Force create master commit after debug
         @param job_slug: Slug of a job to upload the files to
         @param git_diff: upload only files from git diff output
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param message: String defining the commit message
         @param output_dir: String will only sync the files in the output_dir specified
-        @return: None
+        @return: commit sha1
         """
         try:
-            self.download(sync=True, progress_bar_enabled=progress_bar_enabled)
-            self.upload(sync=True, progress_bar_enabled=progress_bar_enabled, job_slug=job_slug, git_diff=git_diff,
-                        message=message, output_dir=output_dir)
+            if self._should_download():
+                self.download(sync=True, progress_bar_enabled=progress_bar_enabled)
+            commit_sha1 = self.upload(sync=True, progress_bar_enabled=progress_bar_enabled, job_slug=job_slug,
+                                      git_diff=git_diff,
+                                      message=message, output_dir=output_dir, debug_mode=debug_mode)
+
+            return commit_sha1
         finally:
             # make sure the tmp folder used by download and upload will be deleted
             if os.path.exists(DataOwner.TMP_FOLDER_NAME):
@@ -642,3 +673,58 @@ class DataOwner(DynamicAttributes):
                 "query_raw": query_raw
             }
         )
+
+    def _prepare_cloned_directory(self, old_working_dir, current_dir, override):
+        """
+        Creates the working directory and checks if need to override files
+        @params old_working_dir: The old working directory
+        @params current_dir: clone to current directory
+        @params override: If the clone should override the existing files
+        @return: Boolean
+        """
+        if not current_dir:
+            self.working_dir = "{}/{}".format(old_working_dir, self.slug)
+            if not os.path.exists(self.working_dir):
+                os.makedirs(self.working_dir)
+            elif os.path.exists(self.working_dir + '/' + CONFIG_FOLDER_NAME):
+                if not override:
+                    # If already cloned and override set to false - won't clone again
+                    raise CnvrgAlreadyClonedError(error_messages.PROJECT_ALREADY_CLONED)
+                else:
+                    # If already cloned and override set to true - remove config file so that verify will fail until the
+                    # Data owner is cloned again
+                    shutil.rmtree(self.working_dir + '/' + CONFIG_FOLDER_NAME)
+
+        if current_dir and os.path.exists(self.working_dir + '/' + CONFIG_FOLDER_NAME):
+            if not override:
+                # If already cloned and override set to false - won't clone again
+                raise CnvrgAlreadyClonedError(error_messages.PROJECT_ALREADY_CLONED)
+
+    def _should_download(self):
+        job_type = os.environ.get("CNVRG_JOB_TYPE")
+
+        if job_type == "NotebookSession" and self.git:
+            return False
+        elif job_type == "Experiment":
+            return False
+
+        return True
+
+    def _should_have_enough_space_to_download_commit(self, commit_slug):
+        # Support DataCommit only
+        # TODO: support project commit
+
+        if self.__class__.__name__ != "Dataset":
+            return
+
+        reserved_percentage = int(os.environ.get("DISK_CHECK_RESERVED_PERCENTAGE", 5))
+        hdd = psutil.disk_usage(os.path.abspath('./'))
+
+        free_space = hdd.free
+
+        commit = self.get_commit(commit_slug)
+        commit_size = commit.commit_size
+
+        total_free_space = free_space * ((100 - reserved_percentage) / 100)
+        if total_free_space < commit_size:
+            raise CnvrgNotEnoughSpaceError(error_messages.NOT_ENOUGH_SPACE)
