@@ -7,6 +7,7 @@ from cnvrgv2.proxy import HTTP
 from cnvrgv2.utils.json_api_format import JAF
 from cnvrgv2.utils.log_utils import timestamp_for_logs, MAX_LOGS_PER_SEND, LOGS_TYPE_OUTPUT
 from cnvrgv2.utils.url_utils import urljoin
+import json
 
 
 class TagTypes:
@@ -196,8 +197,6 @@ class WorkflowInstanceBase(DataOwner):
         @param filter: list of logs type to filter ('stdout', 'cnvrg-info', 'cnvrg-error')
         @return: List of the logs
         """
-        # TODO: Check that it works after server changes
-        #  (currently results are not in JAF format, filter expects string with " and not ', so current doesn't work)
         if filter is None:
             filter = ["all"]
         elif type(filter) is not list:
@@ -206,7 +205,7 @@ class WorkflowInstanceBase(DataOwner):
         get_logs_url = urljoin(self._route, routes.WORKFLOW_GET_LOGS_SUFFIX)
 
         attributes = {
-            "filter": str(filter),
+            "filter": json.dumps(filter),
             "search": "",
             **kwargs
         }
