@@ -12,7 +12,8 @@ class File(DynamicAttributes):
         "file_name": str,
         "file_size": str,
         "content_type": str,
-        "object_path": str
+        "object_path": str,
+        "url": str
     }
 
     def __init__(self, context=None, slug=None, attributes=None):
