@@ -6,13 +6,13 @@ from cnvrgv2.modules.base.data_owner import DataOwner
 from cnvrgv2.utils.json_api_format import JAF
 from cnvrgv2.utils.url_utils import urljoin
 from cnvrgv2.utils.validators import attributes_validator, validate_secret_key
-from cnvrgv2.errors import CnvrgArgumentsError
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgFileError
 
 
 class ProjectSettings(DataOwner):
     available_attributes = {
         "title": str,
-        "image": str,
+        "default_image": str,
         "privacy": str,
         "mount_folders": list,
         "env_variables": list,
@@ -134,3 +134,39 @@ class ProjectSettings(DataOwner):
             http_method=HTTP.POST,
             payload=JAF.serialize(type="settings", attributes={"secrets": secrets})
         )
+
+    def setup_git(self, git_repo, branch, token=None, ssh_key=None, ssh_key_type="plain"):
+        if all([token, ssh_key]):
+            raise CnvrgArgumentsError(error_messages.CANT_USE_BOTH_SSH_AND_TOKEN)
+
+        if ssh_key_type not in ("plain", "file"):
+            raise CnvrgArgumentsError(error_messages.INVALID_SSH_KEY_TYPE)
+
+        if ssh_key_type == "file" and ssh_key is not None:
+            try:
+                with open(ssh_key, "r") as file:
+                    ssh_key = file.read()
+            except Exception:
+                raise CnvrgFileError(error_messages.CANT_READ_SSH_KEY_FILE)
+
+        if ssh_key is not None:
+            authentication_method = "sshKey"
+        elif token is not None:
+            authentication_method = "token"
+        else:
+            authentication_method = "public"
+
+        self._proxy.call_api(route=urljoin(self._route, routes.GIT), http_method=HTTP.POST, payload={
+            "git_repo": git_repo,
+            "branch": branch,
+            "token": token,
+            "ssh_key": ssh_key,
+            "authentication_method": authentication_method
+        })
+        self.reload()
+
+    def remove_git(self):
+        self._proxy.call_api(route=urljoin(self._route, routes.GIT), http_method=HTTP.DELETE)
+        self._attributes.pop("git_repo", None)
+        self._attributes.pop("git_branch", None)
+        self._attributes.pop("is_git", None)
