@@ -1,4 +1,5 @@
 from cnvrgv2.errors import CnvrgArgumentsError
+from cnvrgv2.config.config import SSO_VERSION
 from cnvrgv2.config import routes, error_messages
 from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
 from cnvrgv2.proxy import Proxy, HTTP
@@ -30,8 +31,8 @@ class User(DynamicAttributes):
         "organizations": list
     }
 
-    def __init__(self, domain, token, is_capi=True, attributes=None):
-        self._proxy = Proxy(domain=domain, token=token, is_capi=is_capi)
+    def __init__(self, domain, token, sso_version=SSO_VERSION.CAPI, attributes=None):
+        self._proxy = Proxy(domain=domain, token=token, sso_version=sso_version)
         if attributes:
             self._email = attributes["email"]
             attributes["icon"] = None
