@@ -7,8 +7,10 @@ from cnvrgv2.context import Context, SCOPE
 from cnvrgv2.data import ArtifactsDownloader
 from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError
 from cnvrgv2.modules.base.workflow_instance_base import TagTypes, WorkflowInstanceBase
+from cnvrgv2.modules.file import File
 from cnvrgv2.modules.workflows.workflow_utils import WorkflowStatuses, WorkflowUtils
 from cnvrgv2.proxy import HTTP, Proxy
+from cnvrgv2.utils.api_list_generator import api_list_generator
 from cnvrgv2.utils.chart_utils import BarChart, Chart, Heatmap, LineChart, ScatterPlot
 from cnvrgv2.utils.env_helper import ENV_KEYS
 from cnvrgv2.utils.json_api_format import JAF
@@ -17,8 +19,6 @@ from cnvrgv2.utils.log_utils import (
     timestamp_for_logs
 )
 from cnvrgv2.utils.url_utils import urljoin
-from cnvrgv2.utils.api_list_generator import api_list_generator
-from cnvrgv2.modules.file import File
 
 
 class Experiment(WorkflowInstanceBase):
@@ -32,6 +32,8 @@ class Experiment(WorkflowInstanceBase):
         "is_running": bool,
         "terminal_url": str,
         "termination_time": datetime,
+        "end_commit": str,
+        "last_successful_commit": str,
         **WorkflowInstanceBase.available_attributes
     }
 
@@ -145,7 +147,7 @@ class Experiment(WorkflowInstanceBase):
         commit = commit_sha1 if commit_sha1 is not None else self.last_commit
         # Start commit for git project is null
         base_commit = self.start_commit["sha1"] if self.start_commit else None
-        downloader = ArtifactsDownloader(self, base_commit_sha1=base_commit, commit_sha1=commit)
+        downloader = ArtifactsDownloader(self, base_commit_sha1=base_commit, commit_sha1=commit, ignore_branches=True)
         while downloader.in_progress:
             time.sleep(1)
 
@@ -223,7 +225,7 @@ class Experiment(WorkflowInstanceBase):
 
         if type(logs) is not list:
             if type(logs) is str:
-                # give the user the option to only send one string
+                # Give the user the option to only send one string
                 logs = [logs]
             else:
                 raise CnvrgArgumentsError({"level": ARGUMENT_BAD_TYPE % ("str", type(logs))})
