@@ -201,7 +201,7 @@ def get_files_and_dirs_recursive(
             full_paths.append(dir_path)
 
     # Add the folder itself, if it's an empty one
-    if len(os.listdir(root_dir)) == 0:
+    if os.path.isdir(root_dir) and len(os.listdir(root_dir)) == 0:
         dir_path = append_trailing_slash(get_relative_path(root_dir).replace(project_root, ""))
         full_paths.append(dir_path)
 
