@@ -21,7 +21,7 @@ def validate_url(url):
 
 
 def validate_email(email):
-    regex = r'^[a-zA-Z0-9]+[\._]?[a-zA-Z0-9]+[@]\w+[.]\w{2,5}$'
+    regex = r'^[a-zA-Z0-9]+[\._]?[a-zA-Z0-9]+[@]\w+(\.\w+)*\.\w{2,5}$'
     return re.search(regex, email) is not None
 
 
