@@ -103,7 +103,7 @@ class LoadCluster:
                 password = "qwe123"
                 uc = UsersClient(domain=self.args.domain)
                 uc.register(username=username, email=email, password=password)
-                self.cnvrg.add_user(email, role)
+                self.cnvrg.members.add(email, role)
         print("Done creating users.")
 
     def create_large_project(self):
