@@ -275,11 +275,13 @@ class DataOwnerFiles:
             os.chdir(data_owner.slug)
             open(os.getcwd() + "/" + tmp_file2, "a").close()
 
-            data_owner.sync()
+            commit_sha1 = data_owner.sync()
             remote_files_after_sync = [f.file_name for f in data_owner.list_files()]
             local_files_after_sync = [f.name for f in os.scandir(os.getcwd()) if f.name != CONFIG_FOLDER_NAME]
 
             assert all(f in remote_files_after_sync for f in local_files_after_sync)
+            assert commit_sha1 == data_owner.local_commit
+            assert commit_sha1 is not None
 
         finally:
             # Cleanups
@@ -488,9 +490,12 @@ class DataOwnerFiles:
 
         create_full(["new_folder_local/file.txt"])
 
-        data_owner.sync()
+        commit_sha1 = data_owner.sync()
 
         # testing
+        assert commit_sha1 == data_owner.local_commit
+        assert commit_sha1 is not None
+
         server_folders = []
         for folder in list(data_owner.list_folders()):
             server_folders.append(folder._attributes["fullpath"])
@@ -583,8 +588,10 @@ class DataOwnerFiles:
         data_owner.remove_files([filename])
 
         os.chdir(data_owner.slug)
-        data_owner.sync()
+        commit_sha1 = data_owner.sync()
 
+        assert commit_sha1 == data_owner.local_commit
+        assert commit_sha1 is not None
         assert os.path.exists(filename) is False
 
     def data_owner_sync_removed_folder(self, data_owner, tmpdir):
@@ -598,6 +605,37 @@ class DataOwnerFiles:
         data_owner.remove_files([folder_name + "/"])
 
         os.chdir(data_owner.slug)
-        data_owner.sync()
+        commit_sha1 = data_owner.sync()
 
+        assert commit_sha1 == data_owner.local_commit
+        assert commit_sha1 is not None
         assert os.path.exists(folder_name) is False
+
+    def data_owner_zero_size_file(self, data_owner):
+        old_working_dir = os.getcwd()
+        try:
+            # Clone Git Project
+            data_owner.clone()
+            os.chdir(data_owner.slug)
+
+            # Create zero size file
+            folder_name = random_string(5)
+            os.mkdir(folder_name)
+            filename = random_string(5)
+            open("{}/{}".format(folder_name, filename), "a")
+
+            # Upload zero size file
+            data_owner.sync(progress_bar_enabled=True, output_dir=folder_name)
+
+            # Check if file successfully uploaded
+            files = data_owner.list_files()
+            files_list = list(files)
+            assert filename == files_list[0].file_name
+
+        except Exception as e:
+            assert False, "Error: {}".format(e)
+
+        finally:
+            os.chdir(old_working_dir)
+            if os.path.isdir(data_owner.slug):
+                shutil.rmtree(data_owner.slug)
