@@ -1,5 +1,6 @@
 import requests
 
+from cnvrgv2.config.config import SSO_VERSION
 from cnvrgv2.context import Context
 from cnvrgv2.proxy import HTTP, Proxy
 
@@ -27,7 +28,7 @@ class TestProxy:
             obj.domain = "http://localhost:3000"
             obj.token = "sampletoken"
             obj.organization = "test"
-            obj.is_capi = True
+            obj.sso_version = SSO_VERSION.CAPI
 
         mocker.patch.object(Context, "__init__", mock_credentials_init)
         mocker.patch.object(requests, "post", mock_requests_post)
